Module minecraft

Module minecraft 

Models and methods for fetching metadata for Minecraft

Structs

Asset
An asset of the game
AssetIndex
Information about the assets of the game
AssetsIndex
An index containing all assets the game needs
Download
Download information of a file
FeatureRule
A rule which depends on the toggled features of the launcher
JavaVersion
Information about the java version the game needs
LatestVersion
The latest snapshot and release of the game
Library
A library which the game relies on to run
LibraryDownload
Download information of a library
LibraryDownloads
A list of files that should be downloaded for libraries
LibraryExtract
Information delegating the extraction of the library
OsRule
A rule which depends on what OS the user is on
PartialLibrary
A partial library which should be merged with a full library
Rule
A rule deciding whether a file is downloaded, an argument is used, etc.
Version
A game version of Minecraft
VersionInfo
Information about a version
VersionManifest
Data of all game versions of Minecraft

Enums

Argument
A command line argument passed to a program
ArgumentType
The type of argument
ArgumentValue
A container for an argument or multiple arguments
DownloadType
The type of download
Os
An enum representing the different types of operating systems
RuleAction
The action a rule can follow
VersionType
The version type

Constants

CURRENT_FORMAT_VERSION
The latest version of the format the model structs deserialize to
VERSION_MANIFEST_URL
The URL to the version manifest

Functions

merge_partial_library
Merges a partial library to make a complete library