pub struct FeatureRule {
pub is_demo_user: Option<bool>,
pub has_custom_resolution: Option<bool>,
pub has_quick_plays_support: Option<bool>,
pub is_quick_play_singleplayer: Option<bool>,
pub is_quick_play_multiplayer: Option<bool>,
pub is_quick_play_realms: Option<bool>,
}Expand description
A rule which depends on the toggled features of the launcher
Fields
is_demo_user: Option<bool>Whether the user is in demo mode
has_custom_resolution: Option<bool>Whether the user is using a custom resolution
has_quick_plays_support: Option<bool>Whether the launcher has quick plays support
is_quick_play_singleplayer: Option<bool>Whether the instance is being launched to a single-player world
is_quick_play_multiplayer: Option<bool>Whether the instance is being launched to a multi-player world
is_quick_play_realms: Option<bool>Whether the instance is being launched to a realms world