pub struct Version {
pub id: String,
pub type_: VersionType,
pub url: String,
pub time: DateTime<Utc>,
pub release_time: DateTime<Utc>,
pub sha1: String,
pub compliance_level: u32,
pub original_sha1: Option<String>,
}Expand description
A game version of Minecraft
Fields
id: StringA unique identifier of the version
type_: VersionTypeThe release type of the version
url: StringA link to additional information about the version
time: DateTime<Utc>The latest time a file in this version was updated
release_time: DateTime<Utc>The time this version was released
sha1: StringThe SHA1 hash of the additional information about the version
compliance_level: u32Whether the version supports the latest player safety features
original_sha1: Option<String>(Modrinth Provided) The SHA1 hash of the original unmodified Minecraft versions JSON